@@ -190,6 +190,8 @@ setMethodS3("getReadablePathname", "Arguments", function(static, file=NULL, path
     }
     file <- getCharacter(static, file, length=c(1,1));
   }
+  # Ignore 'path'?
+  if (isAbsolutePath(file)) path <- NULL
 
   # Argument 'path':
   if (!is.null(path)) {
@@ -516,11 +518,25 @@ setMethodS3("getWritablePathname", "Arguments", function(static, ..., mustExist=
       # Try to create a file
       filenameT <- basename(tempfile());
       pathnameT <- filePath(path, filenameT);
+
       on.exit({
         if (isFile(pathnameT)) {
-          file.remove(pathnameT);
+          # Try to remove the temporary file
+          res <- FALSE;
+          suppressWarnings({
+            for (tt in 1:maxTries) {
+              res <- file.remove(pathnameT);
+              if (res) break;
+              # If not, wait a bit and try again...
+              Sys.sleep(0.5);
+            }
+          })
+          if (!res) {
+            warning("Failed to remove temporary file: ", sQuote(pathnameT));
+          }
         }
       }, add=TRUE);
+
       tryCatch({
         cat(file=pathnameT, Sys.time());
       }, error = function(ex) {
@@ -1344,6 +1360,9 @@ withoutGString <- function(..., envir=parent.frame()) {
 
 ############################################################################
 # HISTORY:
+# 2014-10-03
+# o Now Arguments$getReadablePathname(file, path) ignores 'path' if
+#   'file' specifies an absolute pathname.
 # 2014-05-04
 # o Added argument 'adjust' to Arguments$getReadablePathname().
 # 2014-01-12
