@@ -14,7 +14,7 @@
 # }
 #
 # \arguments{
-#   \item{object}{An object with named elements such as an @environment, 
+#   \item{object}{An object with named elements such as an @environment,
 #     a @list, or a @data.frame.}
 #   \item{fields}{A @character @vector specifying elements to be copied.
 #      If @NULL, all elements are considered.}
@@ -29,26 +29,29 @@
 # \value{
 #   Returns (invisibly) a @character @vector of the fields copied.
 # }
-# 
+#
 # @examples "../incl/attachLocally.Rex"
 #
 # @author
-# 
+#
 # \seealso{
 #  \code{\link[R.oo:attachLocally.Object]{attachLocally}()} of class Object.
 #  @see "base::attach".
 # }
 #
-# @keyword "utilities" 
+# @keyword "utilities"
 # @keyword "programming"
-#*/######################################################################### 
+#*/#########################################################################
 setMethodS3("attachLocally", "list", function(object, fields=NULL, excludeFields=NULL, overwrite=TRUE, envir=parent.frame(), ...) {
-  if (is.null(fields))
+  if (is.null(fields)) {
     fields <- names(object);
+    # Don't try to attach non-named elements
+    fields <- setdiff(fields, "");
+  }
 
   # Note: we cannot do 'fields <- setdiff(fields, excludeFields)', because
   # that will also remove duplicates!
-  attachedFields <- character(length=0);
+  attachedFields <- character(0L);
   for (field in fields) {
     if (field %in% excludeFields)
       next;
@@ -81,6 +84,9 @@ setMethodS3("attachLocally", "environment", function(object, fields=NULL, ..., e
 
 ############################################################################
 # HISTORY:
+# 2014-01-26
+# o BUG FIX: Now attachLocally() no longer tries to attach elements with
+#   an empty name, e.g. list(a=1, 2).
 # 2011-09-19
 # o Now attachLocally() returns a character vector also of length zero.
 #   Before NULL was returned.
@@ -88,4 +94,4 @@ setMethodS3("attachLocally", "environment", function(object, fields=NULL, ..., e
 # o Added Rdoc comments.
 # o Added argument 'excludeFields'. Method now also returns attached fields.
 # o Created from attachLocally.Object().
-############################################################################ 
+############################################################################
