@@ -4,12 +4,13 @@ library("R.utils")
 # Parsed command-line arguments
 ######################################################################
 # Call:
-expr <- "str(R.utils::cmdArgs(defaults=list(n=2L,a=2)))"
-argsC <- c("Rscript", "-e", expr, "--args", "-e", expr, "-n", "1")
+exprA <- "str(R.utils::cmdArgs(defaults=list(n=2L,a=2)))"
+exprB <- "str(R.utils::cmdArgs(defaults=list(n=3L,a=3)))"
+argsC <- c("Rscript", "-e", exprA, "--args", "-e", exprB, "-n", "1")
 print(argsC)
 
 # Truth:
-args0 <- list(e=expr, n=1)
+args0 <- list(e=exprB, n=1)
 
 args <- cmdArgs(.args=argsC)
 str(args)
@@ -17,7 +18,7 @@ stopifnot(all.equal(args, args0))
 
 
 # Truth:
-args0 <- list(x=3.14, e=expr, n=1L)
+args0 <- list(x=3.14, e=exprB, n=1L)
 
 args <- cmdArgs(defaults=list(n=0L, x=3.14), .args=argsC)
 str(args)
